searchNodes=[{"doc":"A simple composable transaction library that serves as an experimental alternative solution to Ecto.Multi. This library intend to tackle the main problem with Ecto.Multi: Ecto.Multi names are global, which requires the caller of a multi-function to know about the names used in the multi. Composing complex Ecto.Multi can run into name collision if not being careful enough.","ref":"Tx.html","title":"Tx","type":"module"},{"doc":"Compose two transactions. Run second one only if the first one succeeds. This is the &quot;bind&quot; operator if you're familiar with Monad. Example: Tx . pure ( 1 ) |&gt; Tx . and_then ( &amp; { :error , &amp;1 } ) |&gt; Tx . execute ( Repo ) == { :error , 1 }","ref":"Tx.html#and_then/2","title":"Tx.and_then/2","type":"function"},{"doc":"Combine a list of transactions [Tx.t(a)] a single Tx.t([a]) . Tx . concat ( [ Tx . pure ( 1 ) , Tx . pure ( 2 ) ] ) |&gt; Tx . execute ( Repo ) =&gt; { :ok , [ 1 , 2 ] }","ref":"Tx.html#concat/1","title":"Tx.concat/1","type":"function"},{"doc":"Combine two transactions Tx.t(a) and Tx.t(b) into a single Tx.t({a, b}) . Tx . concat ( Tx . pure ( 1 ) , Tx . pure ( 2 ) ) |&gt; Tx . execute ( Repo ) =&gt; { :ok , { 1 , 2 } }","ref":"Tx.html#concat/2","title":"Tx.concat/2","type":"function"},{"doc":"Execute the transaction Tx.t(a) , producing an {:ok, a} or {:error, any()} . Options: rollback_on_error (Default: true): rollback transaction if the final result is an {:error, any() rollback_on_exception (Default: true): rollback transaction if an uncaught exception arises within the transaction. Any options Ecto.Repo.transaction/2 accepts.","ref":"Tx.html#execute/3","title":"Tx.execute/3","type":"function"},{"doc":"Map over the successful result of a transaction. Example: Tx . pure ( 1 ) |&gt; Tx . map ( &amp; ( &amp;1 + 1 ) ) |&gt; Tx . execute ( Repo ) == { :ok , 2 }","ref":"Tx.html#map/2","title":"Tx.map/2","type":"function"},{"doc":"Create a transaction. This function creates a Tx.t() from a function of type (Ecto.Repo.t() -&gt; {:ok, a} | {:error, any()}) . Internally, the new/1 constructor simply returns the function as is. Example: t = fn repo -&gt; { :ok , 42 } end Tx . execute ( Tx . new ( t ) , Repo ) == { :ok , 42 }","ref":"Tx.html#new/1","title":"Tx.new/1","type":"function"},{"doc":"Return a transaction that returns a pure value. Property: Tx . execute ( Tx . pure ( x ) , Repo ) == { :ok , x }","ref":"Tx.html#pure/1","title":"Tx.pure/1","type":"function"},{"doc":"Rollback the current transaction. Example: Tx . new ( fn repo -&gt; if 1 == 1 do Tx . rollback ( repo , &quot;One cannot be equal to one&quot; ) else :fine end end ) |&gt; Tx . execute ( Repo ) returns {:error, &quot;One cannot be equal to one&quot;} immediately, with all previous uncommited changes rolled back.","ref":"Tx.html#rollback/2","title":"Tx.rollback/2","type":"function"},{"doc":"Make an transaction rollback on error. You can use this function to fine-tune the rollback behaviour on specific sub-transactions. Please note that it does not support disabling rollback_on_error for sub-transactions.","ref":"Tx.html#rollback_on_error/2","title":"Tx.rollback_on_error/2","type":"function"},{"doc":"Make a transaction (not to) rollback on exception. Wrap around tx with rollback_on_exception(tx, false) if you avoid tx to rollback on exception. When an exception occurs, you will get an {:error, exception} instead. Please note that it does not support enabling rollback_on_exception for sub-transactions because that's the default behaviour.","ref":"Tx.html#rollback_on_exception/2","title":"Tx.rollback_on_exception/2","type":"function"},{"doc":"The raising version of run/2 . This function should be rarely needed if you use the Tx.Macro.tx macro.","ref":"Tx.html#run!/2","title":"Tx.run!/2","type":"function"},{"doc":"Run a transaction to get its result. This is a generic adapter for extracting a {:ok, a} | {:error, any()} from a transaction when given a repo. For normal transaction tx as a function (default), it simply call tx.(repo) For Ecto.Multi, it creates a sub-transaction to execute it For a non-transactional value, it simply returns the value This function should be rarely needed if you use the Tx.Macro.tx macro.","ref":"Tx.html#run/2","title":"Tx.run/2","type":"function"},{"doc":"Convert a Tx.t(a) into a Multi.t() . You can refer to the transactin's result ( {:ok, a} | {:error, any} ) by name . Ecto . transaction ( to_multi ( pure ( 42 ) , :foo ) ) =&gt; { :ok , %{ foo : { :ok , 42 } } }","ref":"Tx.html#to_multi/2","title":"Tx.to_multi/2","type":"function"},{"doc":"","ref":"Tx.html#t:fn_t/1","title":"Tx.fn_t/1","type":"type"},{"doc":"","ref":"Tx.html#t:t/0","title":"Tx.t/0","type":"type"},{"doc":"","ref":"Tx.html#t:t/1","title":"Tx.t/1","type":"type"},{"doc":"Export macros to allow create complex transactions without boilerplate.","ref":"Tx.Macro.html","title":"Tx.Macro","type":"module"},{"doc":"Create a transaction. import Tx.Macro tx do { :ok , a } &lt;- create_a_tx ( value ) { :ok , b } &lt;- create_b_tx ( a ) { :ok , { a , b } } end will expands into: Tx . new ( fn repo -&gt; with { :ok , a } &lt;- Tx . run ( repo , create_a_tx ( value ) ) , { :ok , b } &lt;- Tx . run ( repo , create_b_tx ( a ) ) do { :ok , { a , b } } end end ) You can use tx/2 if you need to access to a binding to repo from the transaction.","ref":"Tx.Macro.html#tx/1","title":"Tx.Macro.tx/1","type":"macro"},{"doc":"Create a transaction with a binding to repo . The repo binding can be used within the body for raw db operations (e.g. Repo.insert , Repo.update , ...). Example: The following code: import Tx.Macro tx repo do { :ok , value } &lt;- repo . insert ( foo ) { :ok , a } &lt;- create_a_tx ( value ) { :ok , b } &lt;- create_b_tx ( a ) { :ok , { a , b } } end will expands into: Tx . new ( fn repo -&gt; with { :ok , value } &lt;- Tx . run ( repo , repo . insert ( foo ) ) , { :ok , a } &lt;- Tx . run ( repo , create_a_tx ( value ) ) , { :ok , b } &lt;- Tx . run ( repo , create_b_tx ( a ) ) do { :ok , { a , b } } end end )","ref":"Tx.Macro.html#tx/2","title":"Tx.Macro.tx/2","type":"macro"}]